@@ -9,22 +9,30 @@ from ..._utils.constants import DOTENV_FILE
 from ..spinner import Spinner
 
 
+def add_cwd_to_path():
+    import sys
+
+    cwd = os.getcwd()
+    if cwd not in sys.path:
+        sys.path.insert(0, cwd)
+
+
 def environment_options(function):
     function = click.option(
         "--alpha",
-        "domain",
+        "environment",
         flag_value="alpha",
         help="Use alpha environment",
     )(function)
     function = click.option(
         "--staging",
-        "domain",
+        "environment",
         flag_value="staging",
         help="Use staging environment",
     )(function)
     function = click.option(
         "--cloud",
-        "domain",
+        "environment",
         flag_value="cloud",
         default=True,
         help="Use production environment",
